==> flutter_gb_authentication_basic-1.1.1.tar.gz: lib/application/bloc/authentication_basic_bloc/authentication_basic_bloc_event.dart <==
part of 'authentication_basic_bloc.dart';

@freezed
class AuthenticationBasicEvent with _$AuthenticationBasicEvent {
  const factory AuthenticationBasicEvent.initialAuthChecked(AuthenticationData? data) = InitialAuthChecked;
  const factory AuthenticationBasicEvent.getSession() = GetSession;
  const factory AuthenticationBasicEvent.loginWithCredentials({
    required String email,
    required String password,
  }) = LoginWithCredentials;
  const factory AuthenticationBasicEvent.loginWithCredentialsRes({
    required Either<Failure, AuthenticationData> response,
  }) = LoginWithCredentialsRes;
  const factory AuthenticationBasicEvent.authChanged({
    required bool authenticated,
    required AuthenticationData? data,
  }) = AuthChanged;
  const factory AuthenticationBasicEvent.logout({
    required String? sessionToken,
  }) = Logout;
  const factory AuthenticationBasicEvent.signupWithCredentials({
    required AuthSignUpPayload payload,
  }) = SignupWithCredentials;

  const factory AuthenticationBasicEvent.signupWithCredentialsResult({
    required AuthSignUpPayload payload,
    required Either<Failure, AuthenticationData?> result,
  }) = SignupWithCredentialsResult;

  const factory AuthenticationBasicEvent.autoSignupAuthResult({
    required Either<Failure, AuthenticationData> result,
  }) = AutoSignupAuthResult;

  const factory AuthenticationBasicEvent.fetchAuthUserData({
    required AuthenticationData authData,
  }) = FetchAuthUserData;
  const factory AuthenticationBasicEvent.fetchAuthUserDataResult({
    required Either<Failure, User> result,
  }) = FetchAuthUserDataResult;

  const factory AuthenticationBasicEvent.sessionExpired({
    required AuthenticationData authData,
  }) = SessionExpired;

  const factory AuthenticationBasicEvent.refreshTokenSuccess({
    required Map<String, dynamic> tokens,
  }) = RefreshTokenSuccess;
  const factory AuthenticationBasicEvent.refreshTokenFailure({
    required String token,
    required dynamic exception,
  }) = RefreshTokenFailure;

  const factory AuthenticationBasicEvent.deleteAccount() = DeleteAccount;
  const factory AuthenticationBasicEvent.deleteAccountResult({required Either<Failure, User?> result}) =
      DeleteAccountResult;
}

==> flutter_gb_authentication_basic-3.0.3.tar.gz: lib/application/bloc/authentication_basic_bloc/authentication_basic_bloc_event.dart <==
part of 'authentication_basic_bloc.dart';

@freezed
class AuthenticationBasicEvent with _$AuthenticationBasicEvent {
  const factory AuthenticationBasicEvent.initialAuthChecked(AuthenticationData? data) = InitialAuthChecked;
  const factory AuthenticationBasicEvent.getSession() = GetSession;
  const factory AuthenticationBasicEvent.loginWithCredentials({
    required String email,
    required String password,
  }) = LoginWithCredentials;
  const factory AuthenticationBasicEvent.loginWithCredentialsRes({
    required Either<Failure, AuthenticationData> response,
  }) = LoginWithCredentialsRes;
  const factory AuthenticationBasicEvent.authChanged({
    required bool authenticated,
    required AuthenticationData? data,
  }) = AuthChanged;
  const factory AuthenticationBasicEvent.logout({
    required String? sessionToken,
  }) = Logout;
  const factory AuthenticationBasicEvent.signupWithCredentials({
    required AuthSignUpPayload payload,
  }) = SignupWithCredentials;

  const factory AuthenticationBasicEvent.signupWithCredentialsResult({
    required AuthSignUpPayload payload,
    required Either<Failure, AuthenticationData?> result,
  }) = SignupWithCredentialsResult;

  const factory AuthenticationBasicEvent.autoSignupAuthResult({
    required Either<Failure, AuthenticationData> result,
  }) = AutoSignupAuthResult;

  const factory AuthenticationBasicEvent.fetchAuthUserData({
    required AuthenticationData authData,
  }) = FetchAuthUserData;
  const factory AuthenticationBasicEvent.fetchAuthUserDataResult({
    required Either<Failure, User> result,
  }) = FetchAuthUserDataResult;

  const factory AuthenticationBasicEvent.sessionExpired({
    required AuthenticationData authData,
  }) = SessionExpired;

  const factory AuthenticationBasicEvent.refreshTokenSuccess({
    required Map<String, dynamic> tokens,
  }) = RefreshTokenSuccess;
  const factory AuthenticationBasicEvent.refreshTokenError({
    required String token,
    required dynamic exception,
    required Failure failure,
  }) = RefreshTokenError;

  const factory AuthenticationBasicEvent.deleteAccount() = DeleteAccount;
  const factory AuthenticationBasicEvent.deleteAccountResult({required Either<Failure, User?> result}) =
      DeleteAccountResult;
}
